Sharing State
=============

.. autoclass:: usim.Lock
    :members:

.. autoclass:: usim.Channel
    :members:

.. autoclass:: usim.Queue
    :members:

.. autoexception:: usim.StreamClosed
    :members:
